@@ -1422,6 +1422,8 @@ int *r, *g, *b, depth;
    char *getenv();
    char *ptr;
    int  use_wrb_colormap = CN_FALSE;
+   extern int custom_palette[32][3];
+   extern int using_custom_palette;
 
    /* Reset the index */
    if (x < 0)   x = 0;
@@ -1433,22 +1435,32 @@ int *r, *g, *b, depth;
       return;
    }
  
-   /* Use special colormap */
-   if ((ptr = getenv("MTV_WRB_COLORMAP")) != NULL) {
-      CNstring_to_lower(ptr);
-      if ((strcmp(ptr,"off")==0) || (strcmp(ptr,"false")==0))
-         use_wrb_colormap = CN_FALSE;
-      else
-         use_wrb_colormap = CN_TRUE;
-   }
- 
-   /* Use hand-picked color scale */
-   if (use_wrb_colormap) {
-      /* white-red-blue color map */
-      colorscale_wrb(x,r,g,b);
+   /* MOD BY PJ 6.10.1995: Custom palette possibility */
+   if (using_custom_palette) {
+
+	   *r = custom_palette[x][0];
+	   *g = custom_palette[x][1];
+	   *b = custom_palette[x][2];
+
    } else {
-      /* red-green-blue color map */
-      colorscale_rgb(x,r,g,b);
+   
+	   /* Use special colormap */
+	   if ((ptr = getenv("MTV_WRB_COLORMAP")) != NULL) {
+		   CNstring_to_lower(ptr);
+		   if ((strcmp(ptr,"off")==0) || (strcmp(ptr,"false")==0))
+			   use_wrb_colormap = CN_FALSE;
+		   else
+			   use_wrb_colormap = CN_TRUE;
+	   }
+ 
+	   /* Use hand-picked color scale */
+	   if (use_wrb_colormap) {
+		   /* white-red-blue color map */
+		   colorscale_wrb(x,r,g,b);
+	   } else {
+		   /* red-green-blue color map */
+		   colorscale_rgb(x,r,g,b);
+	   }
    }
 
    /* Check bounds */
