@@ -52,6 +52,7 @@ int           plot_mult;  /* All plots in a single multi-paned window */
 int           filelist_mode;   /* Read list of input file names from stdin */
 static int    earlydelete;     /* Delete datafile after having read in */
 int           plot_GIF;        /* Dump as GIF immediately after drawn in X window */
+int           exit_after_dumping_GIF;
 
 /*
  * Data storage
@@ -127,7 +128,7 @@ char **argv;
    CNdelete_dataset_list(&data_listhead, &data_listtail);
 
    /* Quit */
-   (void) fprintf(stdout,"Congratulations!!!  You have been TERMINATED...\n");
+   /*(void) fprintf(stdout,"Congratulations!!!  You have been TERMINATED...\n");*/
    exit(0);
 }
 
@@ -184,6 +185,7 @@ char *pgname;
    postscript        = CN_TRUE;
    printplot         = CN_FALSE;
    plot_GIF          = CN_FALSE;
+   exit_after_dumping_GIF = CN_FALSE;
    noxplot           = CN_FALSE;
    landscape         = CN_FALSE;
    scale             = 1.00;
@@ -457,6 +459,13 @@ char** argv;
 		  continue;
       }
 
+	  /* MOD BY PJ 20.12.1995: Added option -exit_after_gif */
+	  if (strcmp(argv[i],"-exit_after_gif") == 0) {    /* Exit immediately after dumping as GIF - used in conjunction with -gifsave */
+		  exit_after_dumping_GIF = CN_TRUE;
+		  (void) fprintf(stdout,"   Commands: Exit after dumping GIF = ON\n");
+		  continue;
+	  }
+	  
       if (argv[i][0] == '-') err = CN_TRUE;
 
       if (argv[i][0] != '-' && argv[i][0] != '=') {
@@ -521,6 +530,7 @@ char *progname;
 [-earlydelete] \
 [-print] \
 [-gifsave] \
+[-exit_after_gif] \
 [-nopixmap] \
 [-geom <geometry>] \
 [-title <window-title>] \
